;----------------------------------------------------------------
;     Exploring Transitions toward Sustainable Construction:
;      The Case of nZEBs (near-zero energy buildings) in NL 
;                 Built by Cesar Garcia-Diaz
;      This version: May 15, 2014. 21.15 Hrs. (UTC/GMT - 5) 
;----------------------------------------------------------------

;----------------------------------------------------------------
;    VARIABLE / AGENT DEFINITIONS & DECLARATIONS
;----------------------------------------------------------------

breed [municipalities municipality]           
breed [developers developer]
breed [contractors contractor] ;not used in this version
breed [clients client] ;not used in this version
breed [conectores conector] ;auxiliary agents used for setting the grid

patches-own [patch-id       ;patch id
             comfort-normal ;indicates level of comfort of the to-be-built normal house on this patch, between 1 and 10
             comfort-nZEB   ;indicates level of comfort of the to-be-built nZE house on this patch, between 1 and 10
             house-type     ;indicate house type
             constructor    ;developer's id
]

municipalities-own [land-sale-fraction         ;amount of land sale (%) that goes to the municipality
                    energy-saving-fraction     ;amount of energy savings per house that benefits the municipality  
                    adoption-rate              ;to be used in modeling municipalitie's attention (Q-learning-like algorithm)
                    Qland                      ;Q-value for land (municipalities)
                    QnZEB                      ;Q-value for nZEBs (municipalities)
                    land-sale-request-queue    ;handles land sales requests
                    construction-request-queue ;handles construction permits
]

developers-own [developer-utility ;utility function
                time              ;construction time 
]


globals [time-horizon  ;simulation horizon
         land-price    ;land price
         Enormal       ;default average amount of consumed energy in normal buildings / houses
         EnZEB         ;near-zero building average energy consumption
         Cnormal       ;cost of building a normal house
         CnZEB         ;cost of building an nZEB
         markup        ;markup percentage over cost 
         Pnormal       ;sale price of a normal home
         PnZEB         ;sale price of an nZEB
         theta1        ;parameter PnZEB equation
         theta2        ;parameter PnZEB equation
         N             ;number of sold nZE homes  
         t-normal      ;time to build a normal house
         t-nZEB        ;time to build an nZE home
         phi           ;scale parameter client's propensity to buy (probability to buy)
         ;gamma1        ;inverse-price elasticity of client's propensity to buy, 0.1 <= gamma1 <= 0.9 / Defined as slider (interface)
         gamma2        ;comfort elasticity of client's propensity to buy, 0.1 <= gamma1 <= 0.9, gamma2 = 1 - gamma1 
         Uo            ;utility participation constraint
]


;--------------------------------------------------------
;                 SETUP PROCEDURE
;--------------------------------------------------------

to setup
   clear-all
   random-seed (100 * timer)
   set-default-shape conectores "square"
   set-default-shape municipalities "square"
   set-default-shape developers "square"
   setup-grid
   setup-global-coefficients
   setup-municipalities
   setup-developers
   setup-contractors
   setup-clients
   reset-ticks
end

to setup-grid ;lattice configuration must set origin point at the corner
   ask patches [set pcolor white
                set patch-id pxcor * 100 + pycor
   ] 
   let x 0
   let y 0
   while [y < max-pycor] [
          set x 0
          while [x < max-pycor] [
                 ask patch x y [
                     sprout-conectores 1 [set color gray + 3 ;sprout automatically sets x y according to patch location
                                          set size 0.2
                                         ]
                 ]
                 set x x + 1
                 
         ]
         set y  y + 1 
    
   ]
   
   ask conectores [
       create-links-with turtles-on neighbors4 [
                         set color gray + 3
                         set thickness 0.2
       ]  
     
   ]
   
   ask conectores [setxy xcor + 0.5 ycor + 0.5]    
end

to setup-global-coefficients
   set time-horizon 5000
   set land-price 50
   set Enormal 10
   set EnZEB 5 ;EnZEB < Enormal
   set Cnormal 50
   set CnZEB Cnormal * 2 ;CnZEB > Cnormal
   set markup 1 
   set Pnormal (Cnormal + land-price) * (markup + 1)
   set theta1 Pnormal * scale-factor-theta1 ;theta1 > Pnormal to guarantee an initial PnZEB > Pnormal; scale-factor-theta1 defined as a slider 
   set theta2 -0.1
   set N 0
   set PnZEB theta1  ;PnZEB > Pnormal. PnZEB = (theta1 * ((nZEB_ready + 1) ^ theta2)), where nZEB_ready = number of nZE homes for sale
   set t-normal 5
   set t-nZEB t-normal * 2
   ;set gamma1 defined as slider (interface). Value strictly between 0 and 1
   set gamma2 1 - gamma1 
   
   ;the following assures that the propensity-to-buy-nZEB and propensity-to-buy-normal are between 0 and 1:
   ;highest utility value is used to normalize utility function: ((1 / Pnormal) ^ gamma1) * (10 ^ gamma2)   
   set phi 1 / (((1 / Pnormal) ^ gamma1) * (10 ^ gamma2))
   
   ;utility participation constraint (this is the minimum utility value a consumer is willing to accept in order to consider buying a house)
   set Uo phi * (1 / (Pnormal * 2)) ^ gamma1 * (1 ^ gamma2) ; "Pnormal * 2" is the maximum possible price jointly with a minimum comfort of "1" 
end

to setup-municipalities
   create-municipalities 1 [
       setxy 0 0
       set color white ;invisible agent on the interface
       set land-sale-fraction 0.3
       set energy-saving-fraction 0.1 ;energy-saving-fraction * Enormal < land-price 
       set adoption-rate 0.75 
       set Qland 1 ;initial value
       set QnZEB 1 ;initial value
       set land-sale-request-queue [] ;initializes empty queue
       set construction-request-queue [] ;initializes empty queue 
   ]
end

to setup-developers
   create-developers 10 [
        let var-x (random max-pxcor) - 1 
        set xcor max list var-x 1        
        let var-y (random max-pycor) - 1 
        set ycor max list var-y 1
        set color blue
        set developer-utility 0
        set size 0.5
        set time 0 ;initial value than means no constructing yet
        let temp-var who
        ask patch-here [set constructor temp-var]
   ]
end

to setup-contractors
   ;generation depends on developers' call. Nothing to add here.
end

to setup-clients
   ;generation depends on house prices. Nothing to add here.   
end


;--------------------------------------------------------
;                 MODEL DYNAMICS
;--------------------------------------------------------  

to go
   if ticks >= time-horizon [stop]
   generate-land-sale-request
   municipality-decision-and-construction
   update-dynamics
   tick

end


to generate-land-sale-request
   let xpos 0
   let ypos 0
   let counter 1
   while [counter <= 3] [ ;the maximum number of generated land sale requests per iteration is three
      if [who] of developers with [pcolor = white] != [] [;this detects developers placed in white patches
         
         ask n-of 1 developers with [pcolor = white] [;"white" indicates idle land 
              set pcolor red ;patch where developer is placed changes color; "red" indicates requesting permit for land sale
              set xpos xcor
              set ypos ycor
          ]  
          ask patch xpos ypos [;recall this patch has labeled as a "red" patch, indicating a land sale procedure
              let temp-var patch-id
              ask municipalities [;recall there is only one municipality
                  set land-sale-request-queue lput temp-var land-sale-request-queue
              ]
          ]
      ]
      set counter counter + 1
   ]
end

to municipality-decision-and-construction
   ask municipalities [
       let total-q-sum (Qland + QnZEB)
       let temp-prob 0 ;initialization
       ifelse total-q-sum != 0 [
              set temp-prob Qland / total-q-sum
       ] 
       [set temp-prob 0.5
       ]
       let draw random-float 1
       ifelse draw <= temp-prob [
          ;gives permission to sell land / sales are registered and Q values are updated / developer starts construction / queues are updated
          if (length land-sale-request-queue) > 0  [
             let temp-var item 0 land-sale-request-queue
             ask patches with [patch-id = temp-var] [
                 set pcolor yellow ;a "yellow" patch indicates a sold land
             ]
             ;the following line allows to find the developer associated with the respective patch
             ask developers with [patch-id = temp-var] [set developer-utility developer-utility - land-price] 
             set Qland ((1 - adoption-rate) * Qland + adoption-rate * land-sale-fraction * land-price)
             set land-sale-request-queue remove-item 0 land-sale-request-queue ;queue update
             set construction-request-queue lput temp-var construction-request-queue ;a sold land immediately requests a construction permission request      
          ]
       ]
       [;else: give permission to build
        ;developer decides whether building a normal home or a nZE home according to demand requirements 
        if (length construction-request-queue) > 0  [
           let temp-var item 0 construction-request-queue ;selects next patch in queue
           let temp-var1 item 0 ([who] of developers with [patch-id = temp-var]) ;identifies which developer is standing on this patch
           ask patches with [patch-id = temp-var] [
              ;comfort is a random integer between 1 an 10, both normal and nZE homes can offer high or low comfort
              set comfort-normal (random 10) + 1  
              set comfort-nZEB (random 10) + 1
           ]
           ;developer has to define which house type to build
           ask developer temp-var1 [     
               ;decides if building a normal o nZEB according to expected utilities
               ;sets corresponding time for finishing construction
               
               ;notice it is possible to retrieve patch info from developer info: the following two (comment) lines yield same result
               ;*ask patches with [patch-id = temp-var] [show comfort-normal] 
               ;*show comfort-normal
               let propensity-to-buy-normal phi * ((1 / Pnormal) ^ gamma1) * (comfort-normal ^ gamma2) 
               
               if (propensity-to-buy-normal < Uo) [set propensity-to-buy-normal 0] 
               let profits-normal (Pnormal  - Cnormal) * propensity-to-buy-normal - land-price
               ;show propensity-to-buy-normal ;control statement
                              
               let propensity-to-buy-nZEB phi * ((1 / PnZEB) ^ gamma1) * (comfort-nZEB ^ gamma2) ;recall it is possible to retrieve patch info from developer info
               if (propensity-to-buy-nZEB < Uo) [set propensity-to-buy-nZEB 0] 
               let profits-nZEB (PnZEB - CnZEB) * propensity-to-buy-nZEB - land-price
               ;show propensity-to-buy-nZEB ; control statement
                              
               ifelse (profits-normal > profits-nZEB) and (profits-normal > 0) [;decision is to build a normal house
                      ask patches with [patch-id = temp-var] [
                          set pcolor gray + 3
                          set house-type "normal"]   
                      set time t-normal + 1 ;clock initializes one time unit ahead
                       
                         
               ] 
               [if (profits-nZEB > profits-normal) and (profits-nZEB > 0) [ 
                      ;decision is to build a nZE house
                      ask patches with [patch-id = temp-var] [
                          set pcolor green + 3
                          set house-type "nZEB"]
                      set time t-nZEB + 1 ;clock initializes one time unit ahead
                      ]     
               ]
        
           ]
        set construction-request-queue remove-item 0 construction-request-queue ;updates queue
        ]
        
       ]
 
    ]
  
end

to update-dynamics
   ;updates of construction times / in case of finished constructions, relocate developers
   ask developers with [time >= 1] [
     ifelse time > 1 [
            set time time - 1    
     ]
     [if time = 1 [ ;time = 1 means that, at this time step, the house is finished (time becomes 0)
         set time 0
         ifelse house-type = "normal" [
           set developer-utility developer-utility - Cnormal]
           [if house-type = "nZEB" [set developer-utility developer-utility - CnZEB]] ;this identifies they house type of the patch this developers is at
         ifelse (pcolor = gray + 3) [set pcolor gray + 1][if pcolor = (green + 3) [set pcolor green + 1]] 
         let new-x-pos 0
         let new-y-pos 0
         let new-developer who
         if [patch-id] of patches with [pcolor = white and pxcor > 0 and pxcor < 25 and pycor > 0 and pycor < 25] != [] [
            ask n-of 1 patches with [pcolor = white and pxcor > 0 and pxcor < 25 and pycor > 0 and pycor < 25] [;patches on grid go from 1...24 in both X and Y
                     set new-x-pos pxcor
                     set new-y-pos pycor
                     set constructor new-developer
            ]
            set xcor new-x-pos ;developer is relocated
            set ycor new-y-pos ;developer is relocated
         ]
      ]
     ] 
   ]  
   
   ;update PnZEB according to built nZE homes
   let nZEB_ready count patches with [pcolor = green + 1] ;number of built, ready to sell, nZE houses 
   set PnZEB (theta1 * ((nZEB_ready + 1) ^ theta2))
   
   ;clients buy houses
   ask patches with [pcolor = (gray + 1) or pcolor = (green + 1)] [ ;finished houses

       let propensity-to-buy-normal phi * ((1 / Pnormal) ^ gamma1) * (comfort-normal ^ gamma2)
       if (propensity-to-buy-normal < Uo) [set propensity-to-buy-normal 0] ;utility participation constraint
       
       let propensity-to-buy-nZEB phi * ((1 / PnZEB) ^ gamma1) * (comfort-nZEB ^ gamma2)
       if (propensity-to-buy-nZEB < Uo) [set propensity-to-buy-nZEB 0] ;utility participation constraint   
       ;show propensity-to-buy-normal ;control statement
       ;show propensity-to-buy-nZEB ;control statement
        
       let temp-var random-float 1 ;client`s propensity to buy
              
       if pcolor = (gray + 1) and temp-var <= propensity-to-buy-normal [ 
          set pcolor gray - 2 ;normal house is sold
          ask developer constructor [set developer-utility developer-utility + Pnormal] ;update profits for developer 
       ]
       
       if pcolor = (green + 1) and temp-var <= propensity-to-buy-nZEB [ 
          set pcolor green - 2 ;nZE house is sold
          ask developer constructor [set developer-utility developer-utility + PnZEB] ;update profits for developer 
       ] 
        
   ]
   
   ;update N for sold nZE homes
   set N count patches with [pcolor = green - 2]
       
   ;update QnZEB for municipality (according to the new N and energy consumption)
   ask municipalities [
       if N > 0 [
          set QnZEB (1 - adoption-rate) * QnZEB + adoption-rate * energy-saving-fraction * (Enormal - EnZEB) * N
       ]
   ]
    
end 

;--------------------------------------------------------
;                 OUTPUT REPORTERS
;-------------------------------------------------------- 

to-report diffusion_nZEB
   report N / ((max-pxcor - 1) ^ 2)
end

to-report diffusion_normal
   report (count patches with [pcolor = gray - 2] / ((max-pxcor - 1) ^ 2))
end

to-report prob_land
   let pr_l 0    
   ask municipalities [set pr_l Qland / (Qland + QnZEB)]
   report pr_l
end

to-report prob_nZEB
   let pr_n 0    
   ask municipalities [set pr_n QnZEB / (Qland + QnZEB)]
   report pr_n
end

;Data collected through experiments:
;;diffusion_normal ;percentage of normal houses
;;diffusion_nZEB ;percentage of nZEB houses
;;PnZEB ;Price nZE houses
;;Pnormal ;price normal houses
;;prob_land ;attention probability land
;;prob_nZEB ;attention probability nZEB




  
@#$#@#$#@
GRAPHICS-WINDOW
703
10
1242
570
-1
-1
20.35
1
10
1
1
1
0
0
0
1
0
25
0
25
1
1
1
ticks
30.0

BUTTON
6
12
156
76
setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
324
14
479
75
go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
166
12
309
75
go once
go 
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
21
100
322
331
Percentage number of houses
Time
Normal / nZE homes
0.0
10.0
0.0
1.0
true
true
"" ""
PENS
"nZEB" 1.0 0 -10899396 true "" "plot count patches with [pcolor = green - 2] / ((max-pxcor - 1) ^ 2)"
"Normal" 1.0 0 -7500403 true "" "plot count patches with [pcolor = gray - 2] / ((max-pxcor - 1) ^ 2)"

PLOT
22
343
308
568
Price behavior
Time
Pnormal / PnZEB
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"PnZEB" 1.0 0 -13210332 true "" "plot PnZEB"
"Pnormal" 1.0 0 -11053225 true "" "plot Pnormal"

PLOT
340
101
662
332
Attention probabilities (nZEB / land)
Time
nZEB / land
0.0
10.0
0.0
1.0
true
true
"" ""
PENS
"nZEB" 1.0 0 -13210332 true "" "ask municipalities [plot QnZEB / (QnZEB + Qland)]"
"Land" 1.0 0 -11053225 true "" "ask municipalities [plot Qland / (QnZEB + Qland)]"

SLIDER
342
374
661
407
gamma1
gamma1
0.1
0.9
0.1
0.1
1
NIL
HORIZONTAL

TEXTBOX
344
347
653
368
Propensity-inverse-price elasticity 
11
0.0
1

TEXTBOX
344
418
581
446
gamma2 is the propensity-comfort elasticity\ngamma2 = 1 - gamma1
11
0.0
1

SLIDER
341
474
658
507
scale-factor-theta1
scale-factor-theta1
1.1
5
1.2
0.1
1
NIL
HORIZONTAL

TEXTBOX
342
521
660
563
This parameter controls how high is initial PnZEB with respect to Pnormal
11
0.0
1

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.4
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Experiment1a" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>diffusion_normal ;percentage of normal houses</metric>
    <metric>diffusion_nZEB ;percentage of nZEB houses</metric>
    <metric>PnZEB ;Price nZE houses</metric>
    <metric>Pnormal ;price normal houses</metric>
    <metric>prob_land ;attention probability land</metric>
    <metric>prob_nZEB ;attention probability nZEB</metric>
    <enumeratedValueSet variable="scale-factor-theta1">
      <value value="1.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gamma1">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment1b" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>diffusion_normal ;percentage of normal houses</metric>
    <metric>diffusion_nZEB ;percentage of nZEB houses</metric>
    <metric>PnZEB ;Price nZE houses</metric>
    <metric>Pnormal ;price normal houses</metric>
    <metric>prob_land ;attention probability land</metric>
    <metric>prob_nZEB ;attention probability nZEB</metric>
    <enumeratedValueSet variable="scale-factor-theta1">
      <value value="1.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gamma1">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment1c" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>diffusion_normal ;percentage of normal houses</metric>
    <metric>diffusion_nZEB ;percentage of nZEB houses</metric>
    <metric>PnZEB ;Price nZE houses</metric>
    <metric>Pnormal ;price normal houses</metric>
    <metric>prob_land ;attention probability land</metric>
    <metric>prob_nZEB ;attention probability nZEB</metric>
    <enumeratedValueSet variable="scale-factor-theta1">
      <value value="1.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gamma1">
      <value value="0.9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment2a" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>diffusion_normal ;percentage of normal houses</metric>
    <metric>diffusion_nZEB ;percentage of nZEB houses</metric>
    <metric>PnZEB ;Price nZE houses</metric>
    <metric>Pnormal ;price normal houses</metric>
    <metric>prob_land ;attention probability land</metric>
    <metric>prob_nZEB ;attention probability nZEB</metric>
    <enumeratedValueSet variable="scale-factor-theta1">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gamma1">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment2b" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>diffusion_normal ;percentage of normal houses</metric>
    <metric>diffusion_nZEB ;percentage of nZEB houses</metric>
    <metric>PnZEB ;Price nZE houses</metric>
    <metric>Pnormal ;price normal houses</metric>
    <metric>prob_land ;attention probability land</metric>
    <metric>prob_nZEB ;attention probability nZEB</metric>
    <enumeratedValueSet variable="scale-factor-theta1">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gamma1">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment2c" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>diffusion_normal ;percentage of normal houses</metric>
    <metric>diffusion_nZEB ;percentage of nZEB houses</metric>
    <metric>PnZEB ;Price nZE houses</metric>
    <metric>Pnormal ;price normal houses</metric>
    <metric>prob_land ;attention probability land</metric>
    <metric>prob_nZEB ;attention probability nZEB</metric>
    <enumeratedValueSet variable="scale-factor-theta1">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gamma1">
      <value value="0.9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment3a" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>diffusion_normal ;percentage of normal houses</metric>
    <metric>diffusion_nZEB ;percentage of nZEB houses</metric>
    <metric>PnZEB ;Price nZE houses</metric>
    <metric>Pnormal ;price normal houses</metric>
    <metric>prob_land ;attention probability land</metric>
    <metric>prob_nZEB ;attention probability nZEB</metric>
    <enumeratedValueSet variable="scale-factor-theta1">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gamma1">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment3b" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>diffusion_normal ;percentage of normal houses</metric>
    <metric>diffusion_nZEB ;percentage of nZEB houses</metric>
    <metric>PnZEB ;Price nZE houses</metric>
    <metric>Pnormal ;price normal houses</metric>
    <metric>prob_land ;attention probability land</metric>
    <metric>prob_nZEB ;attention probability nZEB</metric>
    <enumeratedValueSet variable="scale-factor-theta1">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gamma1">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment3c" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>diffusion_normal ;percentage of normal houses</metric>
    <metric>diffusion_nZEB ;percentage of nZEB houses</metric>
    <metric>PnZEB ;Price nZE houses</metric>
    <metric>Pnormal ;price normal houses</metric>
    <metric>prob_land ;attention probability land</metric>
    <metric>prob_nZEB ;attention probability nZEB</metric>
    <enumeratedValueSet variable="scale-factor-theta1">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gamma1">
      <value value="0.9"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
